==> nuxeo-case-management-test-1.3-sources.jar: org/nuxeo/cm/test/CaseManagementTestConstants.java <==
/*
 * (C) Copyright 2006-2009 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     Anahide Tchertchian
 *
 * $Id$
 */

package org.nuxeo.cm.test;

/**
 * @author Anahide Tchertchian
 */
public class CaseManagementTestConstants {

    public static final String CORE_BUNDLE = "org.nuxeo.ecm.core";

    public static final String CASE_MANAGEMENT_API_BUNDLE = "org.nuxeo.cm.api";

    public static final String CASE_MANAGEMENT_CORE_BUNDLE = "org.nuxeo.cm.core";

    public static final String CASE_MANAGEMENT_CORE_TEST_BUNDLE = "org.nuxeo.cm.core.test";

    public static final String CASE_MANAGEMENT_TEST_BUNDLE = "org.nuxeo.cm.test";

    public static final String DIRECTORY_BUNDLE = "org.nuxeo.ecm.directory";

    public static final String USERMANAGER_BUNDLE = "org.nuxeo.ecm.platform.usermanager";

    public static final String TYPES_BUNDLE = "org.nuxeo.ecm.directory.types.contrib";

    public static final String DIRECTORY_SQL_BUNDLE = "org.nuxeo.ecm.directory.sql";

    public static final String TEMPLATE_BUNDLE = "org.nuxeo.ecm.platform.content.template";

}

==> nuxeo-case-management-test-5.7.1-sources.jar: org/nuxeo/cm/test/CaseManagementTestConstants.java <==
/*
 * (C) Copyright 2006-2009 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     Anahide Tchertchian
 *
 * $Id$
 */

package org.nuxeo.cm.test;

/**
 * @author Anahide Tchertchian
 */
public class CaseManagementTestConstants {

    public static final String CORE_BUNDLE = "org.nuxeo.ecm.core";

    public static final String CASE_MANAGEMENT_API_BUNDLE = "org.nuxeo.cm.api";

    public static final String CASE_MANAGEMENT_CORE_BUNDLE = "org.nuxeo.cm.core";

    public static final String CASE_MANAGEMENT_CORE_TEST_BUNDLE = "org.nuxeo.cm.core.test";

    public static final String CASE_MANAGEMENT_TEST_BUNDLE = "org.nuxeo.cm.test";

    public static final String DIRECTORY_BUNDLE = "org.nuxeo.ecm.directory";

    public static final String USERMANAGER_BUNDLE = "org.nuxeo.ecm.platform.usermanager";

    public static final String DIRECTORY_TYPES_BUNDLE = "org.nuxeo.ecm.directory.types.contrib";

    public static final String DIRECTORY_SQL_BUNDLE = "org.nuxeo.ecm.directory.sql";

    public static final String TEMPLATE_BUNDLE = "org.nuxeo.ecm.platform.content.template";

    public static final String CLASSIFICATION_CORE_BUNDLE = "org.nuxeo.ecm.platform.classification.core";

    public static final String ROUTING_CORE_BUNDLE = "org.nuxeo.ecm.platform.routing.core";

    public static final String AUTOMATION_CORE_BUNDLE = "org.nuxeo.ecm.automation.core";

}
